@@ -30,8 +30,8 @@ from monasca_agent.collector.jmxfetch import JMXFetch, JMX_COLLECT_COMMAND
 # CONSTANTS
 AGENT_CONF = "agent.conf"
 DEFAULT_CHECK_FREQUENCY = 15  # seconds
-DEFAULT_STATSD_FREQUENCY = 2  # seconds
-DEFAULT_STATSD_BUCKET_SIZE = 10  # seconds
+DEFAULT_STATSD_FREQUENCY = 20  # seconds
+DEFAULT_STATSD_INTERVAL = 10  # seconds
 LOGGING_MAX_BYTES = 5 * 1024 * 1024
 DEFAULT_CONFIG_DIR = '/etc/monasca/agent'
 DEFAULT_LOG_DIR = '/var/log/monasca/agent'
@@ -191,8 +191,7 @@ def get_config(parse_args=True, cfg_path=None, options=None):
     agent_config = {
         'check_freq': DEFAULT_CHECK_FREQUENCY,
         'monasca_statsd_interval': DEFAULT_STATSD_FREQUENCY,
-        'monasca_statsd_agregator_bucket_size': DEFAULT_STATSD_BUCKET_SIZE,
-        'monasca_statsd_normalize': 'yes',
+        'monasca_statsd_agregator_interval': DEFAULT_STATSD_INTERVAL,
         'monasca_statsd_port': 8125,
         'forwarder_url': 'http://localhost:17123',
         'hostname': None,
@@ -203,7 +202,7 @@ def get_config(parse_args=True, cfg_path=None, options=None):
     }
 
     monasca_statsd_interval = DEFAULT_STATSD_FREQUENCY
-    monasca_statsd_agregator_bucket_size = DEFAULT_STATSD_BUCKET_SIZE
+    monasca_statsd_agregator_interval = DEFAULT_STATSD_INTERVAL
 
     # Config handling
     try:
@@ -262,8 +261,7 @@ def get_config(parse_args=True, cfg_path=None, options=None):
         monasca_statsd_defaults = {
             'monasca_statsd_port': 8125,
             'monasca_statsd_interval': monasca_statsd_interval,
-            'monasca_statsd_agregator_bucket_size': monasca_statsd_agregator_bucket_size,
-            'monasca_statsd_normalize': 'yes',
+            'monasca_statsd_agregator_interval': monasca_statsd_agregator_interval,
         }
         for key, value in monasca_statsd_defaults.iteritems():
             if config.has_option('Main', key):
@@ -277,10 +275,6 @@ def get_config(parse_args=True, cfg_path=None, options=None):
             if config.has_option('Main', 'statsd_forward_port'):
                 agent_config['statsd_forward_port'] = int(config.get('Main', 'statsd_forward_port'))
 
-        # normalize 'yes'/'no' to boolean
-        monasca_statsd_defaults['monasca_statsd_normalize'] = _is_affirmative(
-            monasca_statsd_defaults['monasca_statsd_normalize'])
-
         # Optional config
         # FIXME not the prettiest code ever...
         if config.has_option('Main', 'use_mount'):
@@ -289,31 +283,21 @@ def get_config(parse_args=True, cfg_path=None, options=None):
         if config.has_option('Main', 'autorestart'):
             agent_config['autorestart'] = _is_affirmative(config.get('Main', 'autorestart'))
 
+        if config.has_option('Main', 'system_metrics'):
+            agent_config['system_metrics'] = config.get('Main', 'system_metrics').split(',')
+
         try:
             filter_device_re = config.get('Main', 'device_blacklist_re')
             agent_config['device_blacklist_re'] = re.compile(filter_device_re)
         except ConfigParser.NoOptionError:
             pass
 
+        if config.has_option('Main', 'ignore_filesystem_types'):
+            agent_config['ignore_filesystem_types'] = config.get('Main', 'ignore_filesystem_types').split(',')
+
         if config.has_option('datadog', 'ddforwarder_log'):
             agent_config['has_datadog'] = True
 
-        # Dogstream config
-        if config.has_option("Main", "dogstream_log"):
-            # Older version, single log support
-            log_path = config.get("Main", "dogstream_log")
-            if config.has_option("Main", "dogstream_line_parser"):
-                agent_config["dogstreams"] = ':'.join(
-                    [log_path, config.get("Main", "dogstream_line_parser")])
-            else:
-                agent_config["dogstreams"] = log_path
-
-        elif config.has_option("Main", "dogstreams"):
-            agent_config["dogstreams"] = config.get("Main", "dogstreams")
-
-        if config.has_option("Main", "nagios_perf_cfg"):
-            agent_config["nagios_perf_cfg"] = config.get("Main", "nagios_perf_cfg")
-
         if config.has_section('WMI'):
             agent_config['WMI'] = {}
             for key, value in config.items('WMI'):
