@@ -46,7 +46,7 @@ class Gauge(Metric):
     """ A metric that tracks a value at particular points in time. """
 
     def __init__(self, formatter, name, dimensions,
-                 hostname, device_name, delegated_tenant = None):
+                 hostname, device_name, delegated_tenant=None):
         self.formatter = formatter
         self.name = name
         self.value = None
@@ -54,12 +54,10 @@ class Gauge(Metric):
         self.delegated_tenant = delegated_tenant
         self.hostname = hostname
         self.device_name = device_name
-        self.last_sample_time = None
         self.timestamp = time()
 
     def sample(self, value, sample_rate, timestamp=None):
         self.value = value
-        self.last_sample_time = time()
         self.timestamp = timestamp
 
     def flush(self, timestamp, interval):
@@ -81,40 +79,12 @@ class Gauge(Metric):
         return []
 
 
-class BucketGauge(Gauge):
-
-    """ A metric that tracks a value at particular points in time.
-    The difference beween this class and Gauge is that this class will
-    report that gauge sample time as the time that Metric is flushed, as
-    opposed to the time that the sample was collected.
-
-    """
-
-    def flush(self, timestamp, interval):
-        if self.value is not None:
-            res = [self.formatter(
-                metric=self.name,
-                timestamp=timestamp,
-                value=self.value,
-                dimensions=self.dimensions,
-                delegated_tenant=self.delegated_tenant,
-                hostname=self.hostname,
-                device_name=self.device_name,
-                metric_type=MetricTypes.GAUGE,
-                interval=interval,
-            )]
-            self.value = None
-            return res
-
-        return []
-
-
 class Counter(Metric):
 
     """ A metric that tracks a counter value. """
 
     def __init__(self, formatter, name, dimensions,
-                 hostname, device_name, delegated_tenant = None):
+                 hostname, device_name, delegated_tenant=None):
         self.formatter = formatter
         self.name = name
         self.value = 0
@@ -122,11 +92,9 @@ class Counter(Metric):
         self.delegated_tenant = delegated_tenant
         self.hostname = hostname
         self.device_name = device_name
-        self.last_sample_time = None
 
     def sample(self, value, sample_rate, timestamp=None):
         self.value += value * int(1 / sample_rate)
-        self.last_sample_time = time()
 
     def flush(self, timestamp, interval):
         try:
@@ -161,12 +129,10 @@ class Histogram(Metric):
         self.delegated_tenant = delegated_tenant
         self.hostname = hostname
         self.device_name = device_name
-        self.last_sample_time = None
 
     def sample(self, value, sample_rate, timestamp=None):
         self.count += int(1 / sample_rate)
         self.samples.append(value)
-        self.last_sample_time = time()
 
     def flush(self, ts, interval):
         if not self.count:
@@ -233,11 +199,9 @@ class Set(Metric):
         self.hostname = hostname
         self.device_name = device_name
         self.values = set()
-        self.last_sample_time = None
 
     def sample(self, value, sample_rate, timestamp=None):
         self.values.add(value)
-        self.last_sample_time = time()
 
     def flush(self, timestamp, interval):
         if not self.values:
@@ -263,7 +227,7 @@ class Rate(Metric):
     """ Track the rate of metrics over each flush interval """
 
     def __init__(self, formatter, name, dimensions,
-                 hostname, device_name, delegated_tenant = None):
+                 hostname, device_name, delegated_tenant=None):
         self.formatter = formatter
         self.name = name
         self.dimensions = dimensions
@@ -271,12 +235,10 @@ class Rate(Metric):
         self.hostname = hostname
         self.device_name = device_name
         self.samples = []
-        self.last_sample_time = None
 
     def sample(self, value, sample_rate, timestamp=None):
         ts = time()
         self.samples.append((int(ts), value))
-        self.last_sample_time = ts
 
     def _rate(self, sample1, sample2):
         interval = sample2[0] - sample1[0]
